pm4py.algo.conformance.alignments.process\_tree.variants package
================================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.process_tree.variants.approximated

Submodules
----------

pm4py.algo.conformance.alignments.process\_tree.variants.search\_graph\_pt module
---------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.search_graph_pt
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants
   :members:
   :undoc-members:
   :show-inheritance:
